@@ -3,7 +3,8 @@ import dataFrameReducer from "../reducers/DataFramesRedux";
 import codeEditorReducer from "../reducers/CodeEditorRedux";
 import ProjectManagerRedux from "../reducers/ProjectManagerRedux";
 import ExperimentManagerRedux from "../reducers/ExperimentManagerRedux";
-// import dfUpdatesReducer from '../reducers/dfUpdates'
+import ModelManagerRedux from "../reducers/ModelManagerRedux";
+import RichOutputRedux from "../reducers/RichOutputRedux";
 
 const store = configureStore({
     reducer: {
@@ -11,6 +12,8 @@ const store = configureStore({
         codeEditor: codeEditorReducer,
         projectManager: ProjectManagerRedux,
         experimentManager: ExperimentManagerRedux,
+        modelManager: ModelManagerRedux,
+        richOutput: RichOutputRedux,
     },
 });
 
